# Matching Rules
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/matching-rules#overview)
  * [ServiceNow Is the Source](https://help.sap.com/docs/leanix/ea/matching-rules#servicenow-is-the-source)
  * [SAP LeanIX Is the Source](https://help.sap.com/docs/leanix/ea/matching-rules#sap-leanix-is-the-source)
  * [Configuring Matching Rules](https://help.sap.com/docs/leanix/ea/matching-rules#configuring-matching-rules)


Set up rules for matching fact sheets between ServiceNow and SAP LeanIX during the initial synchronization.
